pub fn point_on_quadratic_bezier<T>(points: &[T; 3], t: f64) -> Twhere
T: Interpolatable,Expand description
Returns the point on a quadratic bezier curve at the given parameter.
pub fn point_on_quadratic_bezier<T>(points: &[T; 3], t: f64) -> Twhere
T: Interpolatable,Returns the point on a quadratic bezier curve at the given parameter.